@@ -19,6 +19,10 @@ In order to publish on the MQTT control topic, the host must hold an appropriate
 Certificates are available on request from South Coast Science. The certificate should be indicated using the
 aws_client_auth utility.
 
+In the interactive mode, the aws_mqtt_control command-line interpreter supports history [UP] and [DOWN] keys.
+The mode supports command completion with the [TAB] key and command listing with [TAB][TAB]. Exit from the interactive
+mode with [CTRL-D].
+
 SYNOPSIS
 aws_mqtt_control.py { -p HOSTNAME [-a] | -d TAG SHARED_SECRET TOPIC } { -i | -r [CMD_TOKENS] } [-t TIMEOUT] [-v]
 
@@ -27,6 +31,7 @@ aws_mqtt_control.py -p scs-bbe-002 -r "disk_usage"
 
 FILES
 ~/SCS/aws/aws_client_auth.json
+~/SCS/aws/aws_mqtt_control_history
 
 SEE ALSO
 scs_analysis/aws_client_auth
@@ -35,13 +40,15 @@ scs_analysis/mqtt_peer
 scs_mfr/aws_project
 scs_mfr/shared_secret
 scs_mfr/system_id
+
+BUGS
+If the device is currently uploading a backlog of data, then the control receipt will be held in the device's
+message queue, and the interaction will time out.
 """
 
+import json
+import os
 import sys
-import time
-
-from AWSIoTPythonSDK.exception.operationError import operationError
-from AWSIoTPythonSDK.exception.operationTimeoutException import operationTimeoutException
 
 from scs_analysis.cmd.cmd_mqtt_control import CmdMQTTControl
 
@@ -49,30 +56,34 @@ from scs_core.aws.client.access_key import AccessKey
 from scs_core.aws.client.client import Client
 from scs_core.aws.client.client_auth import ClientAuth
 from scs_core.aws.client.mqtt_client import MQTTClient, MQTTSubscriber
-
 from scs_core.aws.manager.s3_manager import S3PersistenceManager
 
-from scs_core.control.control_datum import ControlDatum
 from scs_core.control.control_handler import ControlHandler
 
-from scs_core.data.datetime import LocalizedDatetime
-from scs_core.data.publication import Publication
-
 from scs_core.estate.mqtt_peer import MQTTPeerSet
 
-from scs_host.comms.stdio import StdIO
+from scs_core.sys.logging import Logging
 
+from scs_host.comms.stdio import StdIO
 from scs_host.sys.host import Host
 
 
+# TODO: when in non-interactive mode, exit return code should be the same as the command
+# --------------------------------------------------------------------------------------------------------------------
+
+EXIT_COMMANDS = ['reboot', 'restart', 'shutdown']
+
 # --------------------------------------------------------------------------------------------------------------------
 
 if __name__ == '__main__':
 
-    key = None
-    client = None
-    pub_comms = None
+    history_filename = os.path.join(Host.scs_path(), AccessKey.aws_dir(), 'aws_mqtt_control_history')
 
+    key = None
+    mqtt_client = None
+
+    stdout = None
+    stderr = None
 
     # ----------------------------------------------------------------------------------------------------------------
     # cmd...
@@ -83,8 +94,10 @@ if __name__ == '__main__':
         cmd.print_help(sys.stderr)
         exit(2)
 
-    if cmd.verbose:
-        print("aws_mqtt_control: %s" % cmd, file=sys.stderr)
+    Logging.config('aws_mqtt_control', verbose=cmd.verbose)
+    logger = Logging.getLogger()
+
+    logger.info(cmd)
 
     try:
         # ------------------------------------------------------------------------------------------------------------
@@ -95,13 +108,13 @@ if __name__ == '__main__':
 
         if cmd.aws:
             if not AccessKey.exists(Host):
-                print("aws_mqtt_control: access key not available", file=sys.stderr)
+                logger.error("AccessKey not available.")
                 exit(1)
 
             try:
                 key = AccessKey.load(Host, encryption_key=AccessKey.password_from_user())
             except (KeyError, ValueError):
-                print("aws_mqtt_control: incorrect password", file=sys.stderr)
+                logger.error("incorrect password")
                 exit(1)
 
             s3_client = Client.construct('s3', key)
@@ -117,12 +130,10 @@ if __name__ == '__main__':
             peer = peer_group.peer(cmd.peer_hostname)
 
             if peer is None:
-                print("aws_mqtt_control: no MQTT peer found for host '%s'." % cmd.peer_hostname,
-                      file=sys.stderr)
+                logger.error("no MQTT peer found for host '%s'." % cmd.peer_hostname)
                 exit(2)
 
-            if cmd.verbose:
-                print("aws_mqtt_control: %s" % peer, file=sys.stderr)
+            logger.info(peer)
 
             device_tag = peer.tag
             key = peer.shared_secret
@@ -137,29 +148,46 @@ if __name__ == '__main__':
         auth = ClientAuth.load(Host)
 
         if auth is None:
-            print("aws_mqtt_control: ClientAuth not available.", file=sys.stderr)
+            logger.error("ClientAuth not available.")
             exit(1)
 
-        if cmd.verbose:
-            print("aws_mqtt_control: %s" % auth, file=sys.stderr)
+        logger.info(auth)
 
         # responder...
         handler = ControlHandler(host_tag, device_tag)
         subscriber = MQTTSubscriber(topic, handler.handle)
 
         # client...
-        client = MQTTClient(subscriber)
+        mqtt_client = MQTTClient(subscriber)
 
-        if cmd.verbose:
-            print("aws_mqtt_control: %s" % client, file=sys.stderr)
-            sys.stderr.flush()
+        logger.info(mqtt_client)
+
+
+        # ------------------------------------------------------------------------------------------------------------
+        # StdIO settings...
+
+        mqtt_client.connect(auth, False)
+
+        if cmd.interactive:
+            try:
+                stdout, stderr = handler.publish(mqtt_client, topic, ['?'], cmd.DEFAULT_TIMEOUT, key)
+            except TimeoutError:
+                logger.error("%s is not available." % device_tag)
+                exit(1)
+
+            if stderr:
+                logger.error("%s device problem: %s." % (device_tag, stderr[0]))
+                exit(1)
+
+            commands = json.loads(stdout[0])
+            vocabulary = [command + ' ' for command in commands]
+
+            StdIO.set(vocabulary=vocabulary, history_filename=history_filename)
 
 
         # ------------------------------------------------------------------------------------------------------------
         # run...
 
-        client.connect(auth, False)
-
         while True:
             # cmd...
             if cmd.interactive:
@@ -173,67 +201,39 @@ if __name__ == '__main__':
             else:
                 cmd_tokens = cmd.cmd_tokens
 
-            # datum...
-            now = LocalizedDatetime.now().utc()
-            datum = ControlDatum.construct(host_tag, device_tag, now, cmd_tokens, key)
-
-            publication = Publication(topic, datum)
-
-            handler.set_outgoing(publication)
-
-            if cmd.verbose:
-                print(datum, file=sys.stderr)
-                sys.stderr.flush()
-
             # publish...
             try:
-                success = client.publish(publication)
+                stdout, stderr = handler.publish(mqtt_client, topic, cmd_tokens, cmd.timeout, key)
+            except TimeoutError:
+                logger.error("%s is not available." % device_tag)
+                exit(1)
 
-                if cmd.verbose:
-                    print("paho: %s" % "1" if success else "0", file=sys.stderr)
+            if stdout:
+                print(*stdout, sep='\n')
+                sys.stdout.flush()
 
-            except (OSError, operationError, operationTimeoutException) as ex:
-                print(ex.__class__.__name__, file=sys.stderr)
-
-            # subscribe...
-            timeout = time.time() + cmd.timeout
-
-            if cmd.receipt or cmd.interactive:
-                while True:
-                    if handler.receipt:
-                        if not handler.receipt.is_valid(key):
-                            raise ValueError("invalid digest: %s" % handler.receipt)
-
-                        if cmd.verbose:
-                            print(handler.receipt, file=sys.stderr)
-
-                        if handler.receipt.command.stderr:
-                            print(*handler.receipt.command.stderr, sep='\n', file=sys.stderr)
-
-                        if handler.receipt.command.stdout:
-                            print(*handler.receipt.command.stdout, sep='\n')
-
-                        break
-
-                    if time.time() > timeout:           # was cmd.interactive and ...
-                        break
-
-                    time.sleep(0.1)
+            if stderr:
+                print(*stderr, sep='\n', file=sys.stderr)
+                sys.stderr.flush()
 
             if not cmd.interactive:
                 break
 
+            if cmd_tokens and cmd_tokens[0] in EXIT_COMMANDS:
+                break
 
-        # ------------------------------------------------------------------------------------------------------------
-        # end...
 
-    except KeyboardInterrupt:
-        if cmd.interactive:
-            print(file=sys.stderr)
+    # ----------------------------------------------------------------------------------------------------------------
+    # end...
 
-        if cmd.verbose:
-            print("aws_mqtt_control: KeyboardInterrupt", file=sys.stderr)
+    except (OSError, TimeoutError):
+        logger.error("device is not available.")
+
+    except (EOFError, KeyboardInterrupt):
+        print(file=sys.stderr)
 
     finally:
-        if client:
-            client.disconnect()
+        StdIO.save_history(history_filename)
+
+        if mqtt_client:
+            mqtt_client.disconnect()
