@@ -23,6 +23,13 @@ the ',' character, and the output is terminated by a ']' character.
 Alternatively, if the node is an array or other iterable type, then it may be output as a sequence (a list of items
 separated by newline characters) according to the -s flag.
 
+The ordering of output nodes is as follows:
+* Exclude mode - by input nodes
+* Default mode - by nodes specified on the command line
+
+WARNING: node ordering is overridden by the internal node structure. Thus the specified ordering: a.b.c, x.b.c, a.b.d
+would be rendered as: a.b.c, a.b.d, x.b.c
+
 SYNOPSIS
 node.py [{ [-x] [-a] | -s }] [-f FILE] [-i INDENT] [-v] [SUB_PATH_1 .. SUB_PATH_N]
 
@@ -43,6 +50,7 @@ array mode:
 {"val": {"hmd": 73.6, "tmp": 10.8}, "rec": "2019-02-17T08:57:53Z"}]
 """
 
+import json
 import sys
 
 from scs_analysis.cmd.cmd_node import CmdNode
@@ -50,6 +58,8 @@ from scs_analysis.cmd.cmd_node import CmdNode
 from scs_core.data.json import JSONify
 from scs_core.data.path_dict import PathDict
 
+from scs_core.sys.logging import Logging
+
 
 # --------------------------------------------------------------------------------------------------------------------
 
@@ -67,9 +77,10 @@ if __name__ == '__main__':
         cmd.print_help(sys.stderr)
         exit(2)
 
-    if cmd.verbose:
-        print("node: %s" % cmd, file=sys.stderr)
-        sys.stderr.flush()
+    Logging.config('node', verbose=cmd.verbose)
+    logger = Logging.getLogger()
+
+    logger.info(cmd)
 
     try:
         # ------------------------------------------------------------------------------------------------------------
@@ -81,12 +92,21 @@ if __name__ == '__main__':
                     source = [file.read()]
 
             except FileNotFoundError:
-                print("node: file not found: %s" % cmd.filename, file=sys.stderr)
+                logger.error("file not found: %s" % cmd.filename)
                 exit(1)
 
         else:
             source = sys.stdin
 
+        if cmd.sequence:
+            for document in source:
+                try:
+                    source = [json.dumps(item) for item in json.loads(document)]
+                except json.JSONDecodeError:
+                    logger.error("invalid document: '%s'" % document.strip())
+                    exit(1)
+                break
+
 
         # ------------------------------------------------------------------------------------------------------------
         # run...
@@ -98,8 +118,7 @@ if __name__ == '__main__':
         first = True
 
         for document in source:
-            jstr = document.strip()
-            datum = PathDict.construct_from_jstr(jstr)
+            datum = PathDict.construct_from_jstr(document)
 
             if datum is None:
                 continue
@@ -132,49 +151,32 @@ if __name__ == '__main__':
             if not target:
                 continue                                # skip empty outputs
 
-            if cmd.sequence:
-                for path in cmd.sub_paths:
-                    node = target.node(path)
-
-                    try:
-                        for item in node:
-                            print(JSONify.dumps(item))
-                            sys.stdout.flush()
-                            output_count += 1
-
-                    except TypeError as ex:
-                        print(ex, file=sys.stderr)
-                        print(JSONify.dumps(node))
-
-            else:
-                if cmd.array:
-                    if first:
-                        print(JSONify.dumps(target), end='')
-                        first = False
-
-                    else:
-                        print(", %s" % JSONify.dumps(target), end='')
+            if cmd.array:
+                if first:
+                    print(JSONify.dumps(target), end='')
+                    first = False
 
                 else:
-                    print(JSONify.dumps(target, indent=cmd.indent))
-                    sys.stdout.flush()
-                    output_count += 1
+                    print(", %s" % JSONify.dumps(target), end='')
+
+            else:
+                print(JSONify.dumps(target, indent=cmd.indent))
+                sys.stdout.flush()
+                output_count += 1
 
 
     # ----------------------------------------------------------------------------------------------------------------
     # end...
 
     except KeyError as ex:
-        print("node: KeyError: %s" % ex, file=sys.stderr)
+        logger.error("KeyError: %s" % ex)
 
     except KeyboardInterrupt:
-        if cmd.verbose:
-            print("node: KeyboardInterrupt", file=sys.stderr)
+        print(file=sys.stderr)
 
     finally:
         if cmd.array:
             print(']')
             output_count = 1
 
-        if cmd.verbose:
-            print("node: documents: %d output: %d" % (document_count, output_count), file=sys.stderr)
+        logger.info("documents: %d output: %d" % (document_count, output_count))
