@@ -33,6 +33,7 @@ import sys
 
 from scs_analysis.cmd.cmd_sample_slope import CmdSampleSlope
 
+from scs_core.data.datetime import LocalizedDatetime
 from scs_core.data.datum import Datum
 from scs_core.data.json import JSONify
 from scs_core.data.linear_regression import LinearRegression
@@ -88,7 +89,7 @@ if __name__ == '__main__':
                 exit(1)
 
             rec_node = datum.node(cmd.iso)
-            rec = Datum.datetime(rec_node)
+            rec = LocalizedDatetime.construct_from_iso8601(rec_node)
 
             if rec is None:
                 print("sample_slope: invalid ISO 8601 value '%s' in %s." % (rec_node, jstr), file=sys.stderr)
